import { Component } from '@angular/core';
import { WebSocketInterface, UA } from 'jssip';
import { RTCSession } from 'jssip/lib/RTCSession';
import { MatToolbarModule } from '@angular/material/toolbar'
import { MatIconModule } from '@angular/material/icon'
import { MatCardModule } from '@angular/material/card'
import { MatButtonModule } from '@angular/material/button'
import { CommonModule } from '@angular/common';
import { MatDialog } from '@angular/material/dialog';
import { DialogCallComponent } from './dialog-call/dialog-call.component';

@Component({
  selector: 'app-root',
  imports: [
    CommonModule,
    MatToolbarModule,
    MatIconModule,
    MatCardModule,
    MatButtonModule
  ],
  templateUrl: './app.component.html',
  styleUrl: './app.component.scss'
})
export class AppComponent {

  private readonly server = '192.168.2.169';
  private readonly wss = `wss://${this.server}:8089/ws`;
  private readonly sip = `sip:1003@${this.server}`;
  private readonly password = '32687548';
  private socket: WebSocketInterface;
  private ua: UA;
  protected isRegistred = false;

  protected readonly apartments = ['1001', '1002', '1004'];

  constructor(
    private dialog: MatDialog
  ) {
    this.socket =  new WebSocketInterface(this.wss);
    this.ua = new UA({
      sockets: [this.socket],
      uri: this.sip,
      password: this.password
    });

    this.ua.start();

    this.ua.on('registered', () => this.isRegistred = true);
    this.ua.on('unregistered', () => this.isRegistred = false);
    this.ua.on('registrationFailed', () => this.isRegistred = false);
    this.ua.on('newRTCSession', (data: any) => {
      var session = data.session as RTCSession;

      if (session.direction === "incoming") {
        session.answer(this.callOptions);
      }

      this.dialog.open(
        DialogCallComponent,
        {
          disableClose: true,
          data: { ramal: session.remote_identity.uri.user, session }
        }
      );

    });

  }

  private get callOptions() {
    return { mediaConstraints: { audio: true, video: false } }
  }

  public makeCall(ramal: string): void {
    this.ua.call(`sip:${ramal}@${this.server}`, this.callOptions);
  }

}
