import { CommonModule } from '@angular/common';
import { Component, Inject } from '@angular/core';
import { MatButtonModule } from '@angular/material/button';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { MatIconModule } from '@angular/material/icon';
import { RTCSession } from 'jssip/lib/RTCSession';

@Component({
  selector: 'app-dialog-call',
  imports: [
    CommonModule,
    MatIconModule,
    MatButtonModule
  ],
  templateUrl: './dialog-call.component.html',
  styleUrl: './dialog-call.component.scss'
})
export class DialogCallComponent {

  protected eventMessage = '';
  protected isMicrophone = true;

  constructor(
    private dialogRef: MatDialogRef<DialogCallComponent>,
    @Inject(MAT_DIALOG_DATA) public value: { ramal: string, session: RTCSession }
  ) {
    const session = value.session;

    session.on('connecting', () => this.eventMessage = 'Conectando...');
    session.on('progress', () => this.eventMessage = 'Chamada em progresso...');
    session.on('failed', () => {
      this.eventMessage = 'Chamada falhou...';
      setTimeout(() => this.dialogRef.close(), 1500);
    });
    session.on('ended', () => {
      this.eventMessage = 'Chamada encerrada...';
      setTimeout(() => this.dialogRef.close(), 1500);
    });
    session.on('accepted', (event: any) => {
      console.log('Chamada aceita...', event);
      this.eventMessage = 'Chamada aceita!';
    });

    session.connection.addEventListener('track', (event: RTCTrackEvent) => {
      const remoteStream = new MediaStream();
      remoteStream.addTrack(event.track);
      const remoteAudio = document.createElement('audio');
      remoteAudio.srcObject = remoteStream;
      remoteAudio.autoplay = true;
      document.body.appendChild(remoteAudio);
    });
  }

  protected hangup() {
    this.value.session.terminate();
  }

  protected microphone() {
    if (this.isMicrophone) {
      this.value.session.mute();
      this.isMicrophone = false;
    } else {
      this.value.session.unmute();
      this.isMicrophone = true;
    }
  }

}
